@@ -348,8 +348,8 @@ def main():
     drlact.triggered.connect(lambda: drlgui.main_window(
         main_window, augCanvas, update))
     tofact = QtWidgets.QAction(QtGui.QIcon.fromTheme(
-        "applications-utilities"), "TO&F...", None)
-    tofact.setShortcut(QtCore.Qt.CTRL + QtCore.Qt.Key_F)
+        "applications-utilities"), "&MOB...", None)
+    tofact.setShortcut(QtCore.Qt.CTRL + QtCore.Qt.Key_M)
     tofact.triggered.connect(lambda: mt.main_window(
         main_window, augCanvas, update))
     aboutact = QtWidgets.QAction("&About Prasopes", None)
