@@ -1,18 +1,8 @@
 #!/usr/bin/env python3
-from matplotlib.backends.backend_qt5agg import\
-        FigureCanvasQTAgg as FigureCanvas
-from matplotlib.figure import Figure
-from PyQt5 import QtCore
-from PyQt5 import QtWidgets
 from PyQt5 import QtGui
-from PyQt5 import QtPrintSupport
 import matplotlib
 import numpy as np
 import prasopes.datatools as dt
-import prasopes.graphtools as gt
-import prasopes.filetools as ft
-import prasopes.config as cf
-import os.path
 import logging
 matplotlib.use("Qt5Agg")
 
