@@ -43,7 +43,7 @@ def update_profile(pt, row, dataset):
     spectrum.clear()
     limits = []
     spectra = dataset.get_spectra(-np.inf, np.inf)
-    for i,spectxy in enumerate(spectra):
+    for i, spectxy in enumerate(spectra):
         massargs = drl.get_massargs(pt, row, spectxy[0])
         spectrum.plot(spectxy[0], spectxy[1], ':', color='gray')
         spectrum.plot(spectxy[0][massargs], spectxy[1][massargs],
@@ -489,6 +489,7 @@ def paste_clip(ds, drls, drlspectrum):
                         and i < table.rowCount():
                     table.item(i, j).setText(col)
 
+
 def paint_override(self, ds, drls, drlspectrum):
     update_drlspectrum(ds, drls, self.plot)
     self.plot.set_xlim(drlspectrum.get_xlim())
@@ -640,8 +641,8 @@ def main_window(parent, augCanvas, update_signal):
     drl_print.clicked.connect(lambda: print_graph(ds, drls))
     drl_export.clicked.connect(lambda: export_drlspectrum(
         main_widget, ds, drls))
-    drl_reactivity.clicked.connect(lambda: rt.main_window(parent,
-        augCanvas, update_signal, drls))
+    drl_reactivity.clicked.connect(lambda: rt.main_window(
+        parent, augCanvas, update_signal, drls))
 
     drls['pt'].itemChanged.connect(lambda item: ptable_changed(
         item.row(), item.column(), ds, drls, chromplot))
