@@ -305,7 +305,7 @@ def autozoomy(ms_spec):
         ms_spec.figure.canvas.draw()
 
 
-def ann_spec(ms_spec, msdata, ann_limit=0.01):
+def ann_spec(ms_spec, msdata, ann_limit=0.01, coef_x=15, coef_y=20):
     """annotate spectrum
 
     First define the array, in which the annotation should occur.
@@ -313,7 +313,10 @@ def ann_spec(ms_spec, msdata, ann_limit=0.01):
     then reduced to a representation of the important ones by the sub_peaks
     function"""
 
-    def sub_peaks(peakz, hardpeaks, xrange, yrange, coef_x=15, coef_y=20):
+    cx = msdata['ancx'] if 'ancx' in msdata.keys() else 15
+    cy = msdata['ancy'] if 'ancy' in msdata.keys() else 20
+
+    def sub_peaks(peakz, hardpeaks, xrange, yrange, coef_x=cx, coef_y=cy):
         """Returns reasonable subselection of local maximas"""
         hardxy = np.array([i.xy for i in hardpeaks], dtype=[
             ('x', np.float32), ('y', np.float32)])
@@ -351,7 +354,7 @@ def ann_spec(ms_spec, msdata, ann_limit=0.01):
     # remove them from tracking
     msdata['annotation'].clear()
 
-    if len(peaks) == 0:
+    if not len(peaks):
         return
     peaks = np.concatenate(peaks)
 
